==> com.liferay.dynamic.data.mapping.form.web-2.0.105.jar: META-INF/resources/admin/js/components/Popover/PopoverBase.es.js <==
Liferay.Loader.define("dynamic-data-mapping-form-web@2.0.105/admin/js/components/Popover/PopoverBase.es", ['module', 'exports', 'require', 'frontend-js-react-web$classnames', 'frontend-js-metal-web$metal-jsx'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = exports.PopoverBase = void 0;

  var _classnames = _interopRequireDefault(require("frontend-js-react-web$classnames"));

  var _metalJsx = _interopRequireWildcard(require("frontend-js-metal-web$metal-jsx"));

  function _getRequireWildcardCache() {
    if (typeof WeakMap !== "function") return null;var cache = new WeakMap();_getRequireWildcardCache = function _getRequireWildcardCache() {
      return cache;
    };return cache;
  }

  function _interopRequireWildcard(obj) {
    if (obj && obj.__esModule) {
      return obj;
    }if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") {
      return { "default": obj };
    }var cache = _getRequireWildcardCache();if (cache && cache.has(obj)) {
      return cache.get(obj);
    }var newObj = {};var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor;for (var key in obj) {
      if (Object.prototype.hasOwnProperty.call(obj, key)) {
        var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null;if (desc && (desc.get || desc.set)) {
          Object.defineProperty(newObj, key, desc);
        } else {
          newObj[key] = obj[key];
        }
      }
    }newObj["default"] = obj;if (cache) {
      cache.set(obj, newObj);
    }return newObj;
  }

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { "default": obj };
  }

  function _typeof(obj) {
    "@babel/helpers - typeof";
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  function _defineProperty(obj, key, value) {
    if (key in obj) {
      Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true });
    } else {
      obj[key] = value;
    }return obj;
  }

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];descriptor.enumerable = descriptor.enumerable || false;descriptor.configurable = true;if ("value" in descriptor) descriptor.writable = true;Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) _defineProperties(Constructor.prototype, protoProps);if (staticProps) _defineProperties(Constructor, staticProps);return Constructor;
  }

  function _possibleConstructorReturn(self, call) {
    if (call && (_typeof(call) === "object" || typeof call === "function")) {
      return call;
    }return _assertThisInitialized(self);
  }

  function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }return self;
  }

  function _getPrototypeOf(o) {
    _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
      return o.__proto__ || Object.getPrototypeOf(o);
    };return _getPrototypeOf(o);
  }

  function _inherits(subClass, superClass) {
    if (typeof superClass !== "function" && superClass !== null) {
      throw new TypeError("Super expression must either be null or a function");
    }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } });if (superClass) _setPrototypeOf(subClass, superClass);
  }

  function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
      o.__proto__ = p;return o;
    };return _setPrototypeOf(o, p);
  }

  var Header = function Header(_ref) {
    var children = _ref.children;
    IncrementalDOM.elementOpen("div", null, null, "class", "popover-header");
    iDOMHelpers.renderArbitrary(children);
    return IncrementalDOM.elementClose("div");
  };

  var Body = function Body(_ref2) {
    var children = _ref2.children;
    IncrementalDOM.elementOpen("div", null, null, "class", "popover-body");
    iDOMHelpers.renderArbitrary(children);
    return IncrementalDOM.elementClose("div");
  };

  var Footer = function Footer(_ref3) {
    var children = _ref3.children;
    IncrementalDOM.elementOpen("div", null, null, "class", "popover-footer");
    iDOMHelpers.renderArbitrary(children);
    return IncrementalDOM.elementClose("div");
  };

  var PopoverBase = /*#__PURE__*/function (_Component) {
    _inherits(PopoverBase, _Component);

    function PopoverBase() {
      _classCallCheck(this, PopoverBase);

      return _possibleConstructorReturn(this, _getPrototypeOf(PopoverBase).apply(this, arguments));
    }

    _createClass(PopoverBase, [{
      key: "render",
      value: function render() {
        var _getCN;

        var _this$props = this.props,
            children = _this$props.children,
            placement = _this$props.placement,
            visible = _this$props.visible;
        var classes = (0, _classnames["default"])('popover', (_getCN = {}, _defineProperty(_getCN, "clay-popover-".concat(placement), placement), _defineProperty(_getCN, 'hide', !visible), _getCN));
        IncrementalDOM.elementOpenStart("div");
        iDOMHelpers.forOwn(this.otherProps(), iDOMHelpers.attr);
        IncrementalDOM.attr("class", classes);
        IncrementalDOM.elementOpenEnd("div");
        iDOMHelpers.renderArbitrary(placement !== 'none' && IncrementalDOM.elementVoid("div", null, null, "class", "arrow"));
        iDOMHelpers.renderArbitrary(children);
        return IncrementalDOM.elementClose("div");
      }
    }]);

    return PopoverBase;
  }(_metalJsx["default"]);

  exports.PopoverBase = PopoverBase;
  PopoverBase.PROPS = {
    /**
     * @type {string}
     * @default undefined
     */
    placement: _metalJsx.Config.oneOf(['bottom', 'left', 'none', 'right', 'top']).value('none'),

    /**
     * @type {boolean}
     * @default false
     */
    visible: _metalJsx.Config.bool().value(false)
  };
  PopoverBase.Header = Header;
  PopoverBase.Body = Body;
  PopoverBase.Footer = Footer;
  var _default = PopoverBase;
  exports["default"] = _default;
  //# sourceMappingURL=PopoverBase.es.js.map
});
//# sourceMappingURL=PopoverBase.es.js.map

==> com.liferay.dynamic.data.mapping.form.web-3.0.19.jar: META-INF/resources/admin/js/components/Popover/PopoverBase.es.js <==
Liferay.Loader.define("dynamic-data-mapping-form-web@3.0.19/admin/js/components/Popover/PopoverBase.es", ['module', 'exports', 'require', 'frontend-js-react-web$classnames', 'frontend-js-metal-web$metal-jsx'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = exports.PopoverBase = void 0;

  var _classnames = _interopRequireDefault(require("frontend-js-react-web$classnames"));

  var _metalJsx = _interopRequireWildcard(require("frontend-js-metal-web$metal-jsx"));

  function _getRequireWildcardCache() {
    if (typeof WeakMap !== "function") return null;var cache = new WeakMap();_getRequireWildcardCache = function _getRequireWildcardCache() {
      return cache;
    };return cache;
  }

  function _interopRequireWildcard(obj) {
    if (obj && obj.__esModule) {
      return obj;
    }if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") {
      return { "default": obj };
    }var cache = _getRequireWildcardCache();if (cache && cache.has(obj)) {
      return cache.get(obj);
    }var newObj = {};var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor;for (var key in obj) {
      if (Object.prototype.hasOwnProperty.call(obj, key)) {
        var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null;if (desc && (desc.get || desc.set)) {
          Object.defineProperty(newObj, key, desc);
        } else {
          newObj[key] = obj[key];
        }
      }
    }newObj["default"] = obj;if (cache) {
      cache.set(obj, newObj);
    }return newObj;
  }

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { "default": obj };
  }

  function _typeof(obj) {
    "@babel/helpers - typeof";
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  function _defineProperty(obj, key, value) {
    if (key in obj) {
      Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true });
    } else {
      obj[key] = value;
    }return obj;
  }

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];descriptor.enumerable = descriptor.enumerable || false;descriptor.configurable = true;if ("value" in descriptor) descriptor.writable = true;Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) _defineProperties(Constructor.prototype, protoProps);if (staticProps) _defineProperties(Constructor, staticProps);return Constructor;
  }

  function _possibleConstructorReturn(self, call) {
    if (call && (_typeof(call) === "object" || typeof call === "function")) {
      return call;
    }return _assertThisInitialized(self);
  }

  function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }return self;
  }

  function _getPrototypeOf(o) {
    _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
      return o.__proto__ || Object.getPrototypeOf(o);
    };return _getPrototypeOf(o);
  }

  function _inherits(subClass, superClass) {
    if (typeof superClass !== "function" && superClass !== null) {
      throw new TypeError("Super expression must either be null or a function");
    }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } });if (superClass) _setPrototypeOf(subClass, superClass);
  }

  function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
      o.__proto__ = p;return o;
    };return _setPrototypeOf(o, p);
  }

  var Header = function Header(_ref) {
    var children = _ref.children;
    IncrementalDOM.elementOpen("div", null, null, "class", "popover-header");
    iDOMHelpers.renderArbitrary(children);
    return IncrementalDOM.elementClose("div");
  };

  var Body = function Body(_ref2) {
    var children = _ref2.children;
    IncrementalDOM.elementOpen("div", null, null, "class", "popover-body");
    iDOMHelpers.renderArbitrary(children);
    return IncrementalDOM.elementClose("div");
  };

  var Footer = function Footer(_ref3) {
    var children = _ref3.children;
    IncrementalDOM.elementOpen("div", null, null, "class", "popover-footer");
    iDOMHelpers.renderArbitrary(children);
    return IncrementalDOM.elementClose("div");
  };

  var PopoverBase =
  /*#__PURE__*/
  function (_Component) {
    _inherits(PopoverBase, _Component);

    function PopoverBase() {
      _classCallCheck(this, PopoverBase);

      return _possibleConstructorReturn(this, _getPrototypeOf(PopoverBase).apply(this, arguments));
    }

    _createClass(PopoverBase, [{
      key: "render",
      value: function render() {
        var _getCN;

        var _this$props = this.props,
            children = _this$props.children,
            placement = _this$props.placement,
            visible = _this$props.visible;
        var classes = (0, _classnames["default"])('popover', (_getCN = {}, _defineProperty(_getCN, "clay-popover-".concat(placement), placement), _defineProperty(_getCN, 'hide', !visible), _getCN));
        IncrementalDOM.elementOpenStart("div");
        iDOMHelpers.forOwn(this.otherProps(), iDOMHelpers.attr);
        IncrementalDOM.attr("class", classes);
        IncrementalDOM.elementOpenEnd("div");
        iDOMHelpers.renderArbitrary(placement !== 'none' && IncrementalDOM.elementVoid("div", null, null, "class", "arrow"));
        iDOMHelpers.renderArbitrary(children);
        return IncrementalDOM.elementClose("div");
      }
    }]);

    return PopoverBase;
  }(_metalJsx["default"]);

  exports.PopoverBase = PopoverBase;
  PopoverBase.PROPS = {
    /**
     * @type {string}
     * @default undefined
     */
    placement: _metalJsx.Config.oneOf(['bottom', 'left', 'none', 'right', 'top']).value('none'),

    /**
     * @type {boolean}
     * @default false
     */
    visible: _metalJsx.Config.bool().value(false)
  };
  PopoverBase.Header = Header;
  PopoverBase.Body = Body;
  PopoverBase.Footer = Footer;
  var _default = PopoverBase;
  exports["default"] = _default;
  //# sourceMappingURL=PopoverBase.es.js.map
});
//# sourceMappingURL=PopoverBase.es.js.map
